@@ -257,15 +257,16 @@ typedef  char         CCKD_ITRACE[256]; /* Trace table entry         */
 #define CCKD_DEF_FREEPEND     -1        /* Def free pending cycles   */
 #define CCKD_MAX_FREEPEND      4        /* Max free pending cycles   */
 
-#define CCKD_MIN_DHMAX         0        /* Min DASD hardeners allowed  */
-#define CCKD_DEF_DHMAX         1        /* Def DASD hardeners allowed  */
-#define CCKD_MAX_DHMAX         1        /* Max DASD hardeners allowed  */
-                                        /* *** ONLY ONE ALLOWED! ***   */
+#define CCKD_DEF_DHSTART       1        /* Def DASD hardener start   */
 
-#define CCKD_MIN_DHINT         0        /* Min DASD hardening interval */
-#define CCKD_DEF_DHINT         0        /* Def DASD hardening interval */
-#define CCKD_MAX_DHINT         999      /* Max DASD hardening interval */
+#define CCKD_MIN_DHINT         0        /* Min DASD hardener interval*/
+#define CCKD_DEF_DHINT         10       /* Def DASD hardener interval*/
+#define CCKD_MAX_DHINT         999      /* Max DASD hardener interval*/
 
+#define CCKD_MIN_DHMAX         0        /* Min DASD hardeners allowed*/
+#define CCKD_DEF_DHMAX         1        /* Def DASD hardeners allowed*/
+#define CCKD_MAX_DHMAX         1        /* Max DASD hardeners allowed*/
+                                        /* *** ONLY ONE ALLOWED ***  */
 
 /*-------------------------------------------------------------------*/
 /*                   Global CCKD dasd block                          */
@@ -293,7 +294,7 @@ struct CCKDBLK {                        /* Global cckd dasd block    */
         int              dha;           /* Number Dasd Hardener threads active */
         int              dhmax;         /* Max Dasd Hardeners        */
         int              dhint;         /* Wait time in seconds      */
-
+        bool             dhstart;       /* 1=start Dasd Hardener     */
         LOCK             gclock;        /* Garbage collector lock    */
         COND             gccond;        /* Garbage collector cond    */
         int              gcs;           /* Number garbage collector threads started */
@@ -301,7 +302,7 @@ struct CCKDBLK {                        /* Global cckd dasd block    */
         int              gcmax;         /* Max garbage collectors    */
         int              gcint;         /* Wait time in seconds      */
         int              gcparm;        /* Adjustment parm           */
-
+        bool             gcstart;       /* 1=start Garbage Collector */
         LOCK             wrlock;        /* I/O lock                  */
         COND             wrcond;        /* I/O condition             */
         int              wrpending;     /* Number writes pending     */
