@@ -2067,7 +2067,7 @@ void Cleanup()
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// Hercules  "daemon_task"  -or-  "panel_display"  override...
+// Hercules  "noui_task"  -or-  "panel_display"  override...
 
 void gui_panel_display ()
 {
@@ -2145,7 +2145,7 @@ HDL_REGISTER_SECTION            // ("Register" our entry-points)
     //             entry-point      entry-point
     //             name             value
     HDL_REGISTER ( panel_display,   gui_panel_display   );// (Yep! We override EITHER!)
-    HDL_REGISTER ( daemon_task,     gui_panel_display   );// (Yep! We override EITHER!)
+    HDL_REGISTER ( noui_task,       gui_panel_display   );// (Yep! We override EITHER!)
     HDL_REGISTER ( debug_cpu_state, gui_debug_cpu_state );
     HDL_REGISTER ( debug_cd_cmd,    gui_debug_cd_cmd    );
     HDL_REGISTER ( panel_command,   gui_panel_command   );
