@@ -244,6 +244,7 @@
 #undef  FEATURE_053_LOAD_ZERO_RIGHTMOST_FACILITY
 #undef  FEATURE_054_EE_CMPSC_FACILITY
 #undef  FEATURE_057_MSA_EXTENSION_FACILITY_5
+#undef  DYNINST_057_MSA_EXTENSION_FACILITY_5               /*dyncrypt*/
 #undef  FEATURE_058_MISC_INSTR_EXT_FACILITY_2
 #undef  FEATURE_061_MISC_INSTR_EXT_FACILITY_3
 #undef  FEATURE_066_RES_REF_BITS_MULT_FACILITY
@@ -288,6 +289,8 @@
 #undef  FEATURE_194_RESET_DAT_PROT_FACILITY
 #undef  FEATURE_196_PROC_ACT_FACILITY
 #undef  FEATURE_197_PROC_ACT_EXT_1_FACILITY
+#undef  FEATURE_198_VECTOR_ENH_FACILITY_3
+#undef  FEATURE_199_VECT_PACKDEC_ENH_FACILITY_3
 
 /*-------------------------------------------------------------------*/
 /*      FEATUREs that DON'T have any facility bits defined           */
