@@ -476,6 +476,14 @@
  #define    _FEATURE_197_PROC_ACT_EXT_1_FACILITY
 #endif
 
+#if defined( FEATURE_198_VECTOR_ENH_FACILITY_3 )
+ #define    _FEATURE_198_VECTOR_ENH_FACILITY_3
+#endif
+
+#if defined( FEATURE_199_VECT_PACKDEC_ENH_FACILITY_3 )
+ #define    _FEATURE_199_VECT_PACKDEC_ENH_FACILITY_3
+#endif
+
 /*-------------------------------------------------------------------*/
 /*                  Non-facility-bit FEATUREs                        */
 /*-------------------------------------------------------------------*/
@@ -1086,6 +1094,34 @@
  #error Processor-Activity-Instrumentation Extension 1 Facility requires Processor-Activity-Instrumentation Facility
 #endif
 
+#if defined( FEATURE_198_VECTOR_ENH_FACILITY_3 ) && !defined( FEATURE_129_ZVECTOR_FACILITY )
+ #error Vector-Enhancements Facility 3 requires z/Architecture Vector Facility
+#endif
+
+#if defined( FEATURE_198_VECTOR_ENH_FACILITY_3 ) && !defined( FEATURE_135_ZVECTOR_ENH_FACILITY_1 )
+ #error Vector-Enhancements Facility 3 requires Vector-Enhancements Facility 1
+#endif
+
+#if defined( FEATURE_198_VECTOR_ENH_FACILITY_3 ) && !defined( FEATURE_148_VECTOR_ENH_FACILITY_2 )
+ #error Vector-Enhancements Facility 3 requires Vector-Enhancements Facility 2
+#endif
+
+#if defined( FEATURE_199_VECT_PACKDEC_ENH_FACILITY_3 ) && !defined( FEATURE_129_ZVECTOR_FACILITY )
+ #error Vector-Packed-Decimal-Enhancement Facility 3 requires z/Architecture Vector Facility
+#endif
+
+#if defined( FEATURE_199_VECT_PACKDEC_ENH_FACILITY_3 ) && !defined( FEATURE_134_ZVECTOR_PACK_DEC_FACILITY )
+ #error Vector-Packed-Decimal-Enhancement Facility 3 requires Vector Packed-Decimal Facility
+#endif
+
+#if defined( FEATURE_199_VECT_PACKDEC_ENH_FACILITY_3 ) && !defined( FEATURE_152_VECT_PACKDEC_ENH_FACILITY )
+ #error Vector-Packed-Decimal-Enhancement Facility 3 requires Vector-Packed-Decimal-Enhancement Facility 1
+#endif
+
+#if defined( FEATURE_199_VECT_PACKDEC_ENH_FACILITY_3 ) && !defined( FEATURE_192_VECT_PACKDEC_ENH_2_FACILITY )
+ #error Vector-Packed-Decimal-Enhancement Facility 3 requires Vector-Packed-Decimal-Enhancement Facility 2
+#endif
+
 /*-------------------------------------------------------------------*/
 /*                  Non-facility-bit FEATUREs                        */
 /*-------------------------------------------------------------------*/
