@@ -96,6 +96,12 @@
 #undef store_dw_noswap
 #undef store_dw
 
+#undef fetch_qw_noswap
+#undef fetch_qw
+
+#undef store_qw_noswap
+#undef store_qw
+
 /*-------------------------------------------------------------------*/
 /*  PROGRAMMING NOTE: the below code should be exactly the same as   */
 /*  the code in "machdep.h" except that where machdep.h defines the  */
@@ -538,6 +544,34 @@ extern inline BYTE cmpxchg8_C11(U64 *old, U64 new, volatile void *ptr);
   #define store_dw(_p, _v) store_dw_noswap((_p), CSWAP64((_v)))
 #endif
 
+/*-------------------------------------------------------------------
+ * fetch_qw_noswap and fetch_qw
+ *-------------------------------------------------------------------*/
+#if !defined(fetch_qw_noswap)
+  #if defined(fetch_qw)
+    #define fetch_qw_noswap(_p) CSWAP128(fetch_qw((_p)))
+  #else
+    extern inline QW fetch_qw_noswap(const void *ptr);
+  #endif
+#endif
+#if !defined(fetch_qw)
+  #define fetch_qw(_p) CSWAP128(fetch_qw_noswap((_p)))
+#endif
+
+/*-------------------------------------------------------------------
+ * store_qw_noswap and store_qw
+ *-------------------------------------------------------------------*/
+#if !defined(store_qw_noswap)
+  #if defined(store_qw)
+    #define store_qw_noswap(_p, _v) store_qw((_p), CSWAP128(_v))
+  #else
+    extern inline void store_qw_noswap(void *ptr, QW value);
+  #endif
+#endif
+#if !defined(store_qw)
+  #define store_qw(_p, _v) store_qw_noswap((_p), CSWAP128((_v)))
+#endif
+
 /*-------------------------------------------------------------------
  * cmpxchg1
  *-------------------------------------------------------------------*/
