@@ -450,9 +450,18 @@
                                                bit 197 is one, bit 196 is
                                                also one.                 */
 
-#define STFL_198_UNDEFINED           198    /* Undefined                 */
-#define STFL_199_UNDEFINED           199    /* Undefined                 */
-#define STFL_200_UNDEFINED           200    /* Undefined                 */
+#define STFL_198_VECTOR_ENH_3        198    /* Vector-enhancements fac-
+                                               ility 3 installed. When
+                                               bit 198 is one, bits 129,
+                                               135 and 148 are also one. */
+
+#define STFL_199_VECT_PACKDEC_ENH_3  199    /* Vector-Packed-Decimal En-
+                                               hancement Facility 3. When
+                                               bit 199 is one, bits 129,
+                                               134, 152 and 192 are also
+                                               one.                      */
+
+#define STFL_200_IBM_INTERNAL        153    /* IBM internal use          */
 
 #define STFL_IBM_LAST_BIT            200    /* Last defined IBM facility */
 
