@@ -47,6 +47,21 @@
 #include "w32ctca.h"
 #endif
 
+#if defined(__FreeBSD__)
+#include <net/if_tun.h>
+#include <net/if.h>
+#include <netinet/in.h>
+#include <netinet/in_var.h>
+#include <libprocstat.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <sys/user.h>
+#include <sys/sysctl.h>
+
+#define FBSD_TUN_EXT 0
+#define FBSD_TUN_INT 1
+#endif
+
 // ====================================================================
 // Declarations
 // ====================================================================
@@ -223,13 +238,116 @@ static int TUNTAP_SetMode (int fd, struct hifr *hifr, int iFlags)
 //      pfd            Pointer to receive the file descriptor of the
 //                       TUN/TAP interface.
 //      pszNetDevName  Pointer to receive the name of the interface.
+//      pinternal      Pointer to receive the origin of the interface:
+//                     1 for devices created by Hercules, 0 for pre-existing
+//                     devices. To be used on systems that impose manual
+//                     removal of devices (e.g. FreeBSD).
 
 int             TUNTAP_CreateInterface( char* pszTUNDevice,
                                         int   iFlags,
                                         int*  pfd,
-                                        char* pszNetDevName )
+                                        char* pszNetDevName,
+                                        int*  pinternal )
 {
     int fd;                        // File descriptor
+
+#if defined (__FreeBSD__)
+    // Were we passed a device name?
+    if(*pszNetDevName) {
+        // Yes, we got a name.
+        char device[PATH_MAX] = "/dev/";
+        strlcat(device, pszNetDevName, sizeof(device));
+
+        fd = TUNTAP_Open( device, O_RDWR );
+
+        // Does it exist?
+        if( fd < 0 ) {
+            if (ENOENT == errno) {
+                // It doesn't exist.
+                WRMSG( HHC99998, "I", "TUNTAP_CreateInterface: Device doesn't exist yet:", device);
+                *pinternal = FBSD_TUN_INT;
+
+                // Open /dev/tun itself to trigger creation of a new device
+                fd = TUNTAP_Open( pszTUNDevice, O_RDWR );
+
+                if( fd < 0 ) {
+                    // Something is not right. Bailing.
+                    WRMSG( HHC00137, "E", pszTUNDevice, strerror( errno ));
+                    return -1;
+                }
+
+                // Setting explicit IFF_POINTOPOINT. Not sure if necessary but...
+                int mode = IFF_POINTOPOINT;
+                if (ioctl(fd, TUNSIFMODE, &mode) < 0) {
+                    WRMSG( HHC00137, "E", pszTUNDevice, strerror( errno ));
+                    return -1;
+                }
+
+                struct ifreq ifr;
+                memset(&ifr, 0, sizeof(ifr));
+
+                if (ioctl(fd, TUNGIFNAME, &ifr) < 0) {
+                    WRMSG( HHC99998, "E", "TUNTAP_CreateInterface: ioctl(fd, TUNGIFNAME, &ifr) failed:", strerror( errno ));
+                    return -1;
+                }
+
+                // What is our current device name and what do we want it to be
+                ifr.ifr_data = pszNetDevName;
+
+                int sock = socket(AF_LOCAL, SOCK_DGRAM, 0);
+                if (sock < 0) {
+                    WRMSG( HHC99998, "E", "TUNTAP_CreateInterface: socket(AF_LOCAL, SOCK_DGRAM, 0) failed:", strerror( errno ));
+                    return -1;
+                }
+
+                if (TUNTAP_IOCtl(sock, SIOCSIFNAME, &ifr) < 0) {
+                    WRMSG( HHC99998, "E", "TUNTAP_CreateInterface: ioctl(sock, SIOCSIFNAME, &ifr) failed:", strerror( errno ));
+                    return -1;
+                }
+
+                close(sock);
+
+            } else {
+                // It exists but we can't work with it. Bailing.
+                WRMSG( HHC00137, "E", pszTUNDevice, strerror( errno ));
+                return -1;
+            }
+        } else {
+            // It exists, and we can open it. Cool.
+            *pinternal = FBSD_TUN_EXT;
+            WRMSG( HHC99998, "I", "TUNTAP_CreateInterface: Device exists and is usable:", device);
+        }
+    } else {
+        // No, we didn't get a name. Create the first available tun device and go with it.
+        *pinternal = FBSD_TUN_INT;
+
+        fd = TUNTAP_Open( pszTUNDevice, O_RDWR );
+        if( fd < 0 ) {
+            // Something is not right. Bailing.
+            WRMSG( HHC00137, "E", pszTUNDevice, strerror( errno ));
+            return -1;
+        }
+
+        struct ifreq ifr;
+        memset(&ifr, 0, sizeof(ifr));
+
+        // Fetching the name of the created device
+        if (ioctl(fd, TUNGIFNAME, &ifr) < 0) {
+            WRMSG( HHC99998, "E", "TUNTAP_CreateInterface: ioctl(fd, TUNGIFNAME, &ifr) failed:", strerror( errno ));
+            return -1;
+        }
+
+        strcpy( pszNetDevName, ifr.ifr_name );
+
+        WRMSG( HHC99998, "I", "TUNTAP_CreateInterface: Device was created:", ifr.ifr_name);
+    }
+
+    *pfd = fd;
+    return 0;
+#else
+
+    *pinternal = 0;
+
 #if !defined( OPTION_W32_CTCI )
     struct utsname utsbuf;
 
@@ -317,6 +435,7 @@ int             TUNTAP_CreateInterface( char* pszTUNDevice,
 #endif // !defined( OPTION_W32_CTCI )
 
     return 0;
+#endif // defined (__FreeBSD__)
 }   // End of function  TUNTAP_CreateInterface()
 
 
@@ -329,6 +448,57 @@ int             TUNTAP_CreateInterface( char* pszTUNDevice,
   #define TUNTAP_IOCtl    IFC_IOCtl
 #endif
 
+//
+// TUNTAP_Close
+//
+//
+// Closes a TUN/TAP network interface.
+//
+// On Linux, TUNTAP_Close is defined as close() but contrary to Linux,
+// FreeBSD does not remove the interface after close()ing it.
+// This leaves the device visible in e.g. ifconfig in a disconnected state.
+// Removing it requires an explicit ioctl.
+//
+// Input:
+//      fd	File descriptor of the TUN/TAP device
+//
+
+#if defined (__FreeBSD__)
+int             TUNTAP_Close( int fd, int internal )
+{
+    struct ifreq ifr;
+    memset(&ifr, 0, sizeof(ifr));
+
+    if (ioctl(fd, TUNGIFNAME, &ifr) < 0) {
+        WRMSG( HHC99998, "E", "TUNTAP_Close: ioctl(fd, TUNGIFNAME, &ifr) failed:", strerror( errno ));
+        return -1;
+    }
+
+    WRMSG( HHC99998, "I", "TUNTAP_Close: Closing", ifr.ifr_name);
+
+    if (close(fd) < 0) {
+        WRMSG( HHC99999, "E", "TUNTAP_Close: Closing the file descriptor failed!");
+        return -1;
+    }
+
+    // Only remove the device from the OS if we created it outselves
+    if (internal) {
+        int sock = socket(AF_INET, SOCK_DGRAM, 0);
+        if (sock < 0) {
+            return -1;
+        }
+
+        if (ioctl(sock, SIOCIFDESTROY, &ifr) < 0) {
+            WRMSG( HHC99998, "E", "TUNTAP_Close: ioctl(sock, SIOCIFDESTROY, &ifr) failed:", strerror( errno ));
+            close(sock);
+            return -1;
+        }
+    }
+
+    return 0;
+}
+#endif
+
 //
 // TUNTAP_ClrIPAddr
 //
@@ -359,6 +529,79 @@ int             TUNTAP_ClrIPAddr( char* pszNetDevName )
 int             TUNTAP_SetIPAddr( char*  pszNetDevName,
                                   char*  pszIPAddr )
 {
+#if defined (__FreeBSD__)
+    int sock = socket(AF_INET, SOCK_DGRAM, 0);
+    if (sock < 0) {
+        return -1;
+    }
+
+    struct ifreq ifr;
+    memset(&ifr, 0, sizeof(ifr));
+    strncpy(ifr.ifr_name, pszNetDevName, IFNAMSIZ);
+
+    // Get current flags - directly because hercifc doesn't know GET ioctls
+    if (ioctl(sock, SIOCGIFFLAGS, &ifr) < 0) {
+        WRMSG( HHC99998, "E", "TUNTAP_SetIPAddr: ioctl(sock, SIOCGIFFLAGS, &ifr) failed:", strerror( errno ));
+        close(sock);
+        return -1;
+    }
+
+    // Set IFF_UP and IFF_POINTOPOINT flags
+    ifr.ifr_flags |= ( IFF_UP | IFF_POINTOPOINT);
+    if (ioctl(sock, SIOCSIFFLAGS, &ifr) < 0) {
+        WRMSG( HHC99998, "E", "TUNTAP_SetIPAddr: ioctl(sock, SIOCSIFFLAGS, &ifr) failed:", strerror( errno ));
+        close(sock);
+        return -1;
+    }
+
+    // Prepwork
+    struct in_aliasreq ifra;
+    memset(&ifra, 0, sizeof(ifra));
+    strncpy(ifra.ifra_name, pszNetDevName, IFNAMSIZ);
+
+    // Local address
+    memset(&ifra.ifra_addr, 0, sizeof(ifra.ifra_addr));
+    ifra.ifra_addr.sin_len = sizeof(struct sockaddr_in);
+    ifra.ifra_addr.sin_family = AF_INET;
+    if (inet_pton(AF_INET, pszIPAddr, &ifra.ifra_addr.sin_addr) != 1) {
+        WRMSG( HHC99998, "E", "TUNTAP_SetIPAddr: inet_pton(AF_INET, pszIPAddr, &ifra.ifra_addr.sin_addr) failed:", strerror( errno ));
+        return -1;
+    }
+
+    // Dest address
+    // We don't know the dest address in this function but the ioctl needs it to set up the device.
+    // We have to set a dummy address which will be overwritten later in TUNTAP_SetDestAddr.
+    // Using an address in the 192.0.2.0/24 range which according to RFC 5737 cannot be used for anything but documentation purposes.
+    char* dummy_ip = "192.0.2.1"; // RFC 5737
+    memset(&ifra.ifra_dstaddr, 0, sizeof(ifra.ifra_dstaddr));
+    ifra.ifra_dstaddr.sin_len = sizeof(struct sockaddr_in);
+    ifra.ifra_dstaddr.sin_family = AF_INET;
+    if (inet_pton(AF_INET, dummy_ip, &ifra.ifra_dstaddr.sin_addr) != 1) {
+        WRMSG( HHC99998, "E", "TUNTAP_SetIPAddr: inet_pton(AF_INET, dummy_ip, &ifra.ifra_dstaddr.sin_addr) failed:", strerror( errno ));
+        return -1;
+    }
+
+    // Netmask
+    // We don't know the netmask either.
+    // Set it to 255.255.255.255 until it gets overwritten later in TUNTAP_SetNetmask.
+    memset(&ifra.ifra_mask, 0, sizeof(ifra.ifra_mask));
+    ifra.ifra_mask.sin_len = sizeof(struct sockaddr_in);
+    ifra.ifra_mask.sin_family = AF_INET;
+    if (inet_pton(AF_INET, "255.255.255.255", &ifra.ifra_mask.sin_addr) != 1) {
+        WRMSG( HHC99998, "E", "TUNTAP_SetIPAddr: inet_pton(AF_INET, \"255.255.255.255\", &ifra.ifra_mask.sin_addr) failed:", strerror( errno ));
+        return -1;
+    }
+
+    if (ioctl(sock, SIOCAIFADDR, &ifra) < 0) {
+        WRMSG( HHC99998, "E", "TUNTAP_SetIPAddr: ioctl(sock, SIOCAIFADDR, &ifra) failed:", strerror( errno ));
+        close(sock);
+        return -1;
+    }
+
+    close(sock);
+    return 0;
+#else
+
     struct hifr         hifr;
     struct sockaddr_in* sin;
 
@@ -385,6 +628,7 @@ int             TUNTAP_SetIPAddr( char*  pszNetDevName,
     }
 
     return TUNTAP_IOCtl( 0, SIOCSIFADDR, (char*)&hifr );
+#endif // defined (__FreeBSD__)
 }   // End of function  TUNTAP_SetIPAddr()
 
 
@@ -395,6 +639,74 @@ int             TUNTAP_SetIPAddr( char*  pszNetDevName,
 int             TUNTAP_SetDestAddr( char*  pszNetDevName,
                                     char*  pszDestAddr )
 {
+#if defined (__FreeBSD__)
+    int sock = socket(AF_INET, SOCK_DGRAM, 0);
+    if (sock < 0) {
+        return -1;
+    }
+
+    struct ifreq ifr;
+
+    // Fetch existing IP
+    memset(&ifr, 0, sizeof(ifr));
+    strncpy(ifr.ifr_name, pszNetDevName, IFNAMSIZ);
+    if (ioctl(sock, SIOCGIFADDR, &ifr) < 0) {
+        WRMSG( HHC99998, "E", "TUNTAP_SetDestAddr: ioctl(sock, SIOCGIFADDR, &ifr) failed:", strerror( errno ));
+        close(sock);
+        return -1;
+    }
+    struct in_addr existing_ip = ((struct sockaddr_in *)&ifr.ifr_addr)->sin_addr;
+
+    // Fetch existing netmask
+    memset(&ifr, 0, sizeof(ifr));
+    strncpy(ifr.ifr_name, pszNetDevName, IFNAMSIZ);
+    if (ioctl(sock, SIOCGIFNETMASK, &ifr) < 0) {
+        WRMSG( HHC99998, "E", "TUNTAP_SetDestAddr: ioctl(sock, SIOCGIFNETMASK, &ifr) failed:", strerror( errno ));
+        close(sock);
+        return -1;
+        }
+    struct in_addr existing_netmask = ((struct sockaddr_in*)&ifr.ifr_addr)->sin_addr;
+
+    // Create request
+    struct in_aliasreq ifra;
+    memset(&ifra, 0, sizeof(ifra));
+    strncpy(ifra.ifra_name, pszNetDevName, IFNAMSIZ);
+
+    struct sockaddr_in* tmp_sin;
+
+    // Source address
+    tmp_sin = (struct sockaddr_in*)&ifra.ifra_addr;
+    tmp_sin->sin_len = sizeof(struct sockaddr_in);
+    tmp_sin->sin_family = AF_INET;
+    tmp_sin->sin_addr = existing_ip;
+
+    // Destination address
+    // We have the 'real' destination IP now, so we can overwrite the RFC 5737 IP.
+    tmp_sin = (struct sockaddr_in*)&ifra.ifra_dstaddr;
+    tmp_sin->sin_len = sizeof(struct sockaddr_in);
+    tmp_sin->sin_family = AF_INET;
+    if (inet_pton(AF_INET, pszDestAddr, &tmp_sin->sin_addr) != 1) {
+        WRMSG( HHC99998, "E", "TUNTAP_SetDestAddr: inet_pton(AF_INET, pszDestAddr, &tmp_sin->sin_addr) failed:", strerror( errno ));
+        close(sock);
+        return 1;
+    }
+
+    // Netmask
+    tmp_sin = (struct sockaddr_in*)&ifra.ifra_mask;
+    tmp_sin->sin_len = sizeof(struct sockaddr_in);
+    tmp_sin->sin_family = AF_INET;
+    tmp_sin->sin_addr = existing_netmask;
+
+    if (ioctl(sock, SIOCAIFADDR, &ifra) < 0) {
+        WRMSG( HHC99998, "E", "TUNTAP_SetDestAddr: ioctl(sock, SIOCAIFADDR, &ifra) failed:", strerror( errno ));
+        close(sock);
+        return -1;
+    }
+
+    close(sock);
+    return 0;
+#else
+
     struct hifr         hifr;
     struct sockaddr_in* sin;
 
@@ -420,6 +732,7 @@ int             TUNTAP_SetDestAddr( char*  pszNetDevName,
     }
 
     return TUNTAP_IOCtl( 0, SIOCSIFDSTADDR, (char*)&hifr );
+#endif // defined (__FreeBSD__)
 }   // End of function  TUNTAP_SetDestAddr()
 
 
@@ -430,6 +743,74 @@ int             TUNTAP_SetDestAddr( char*  pszNetDevName,
 int           TUNTAP_SetNetMask( char*  pszNetDevName,
                                  char*  pszNetMask )
 {
+#if defined (__FreeBSD__)
+    int sock = socket(AF_INET, SOCK_DGRAM, 0);
+    if (sock < 0) {
+        return -1;
+    }
+
+    struct ifreq ifr;
+
+    // Fetch existing IP, set in TUNTAP_SetIPAddr()
+    memset(&ifr, 0, sizeof(ifr));
+    strncpy(ifr.ifr_name, pszNetDevName, IFNAMSIZ);
+    if (ioctl(sock, SIOCGIFADDR, &ifr) < 0) {
+        WRMSG( HHC99998, "E", "TUNTAP_SetNetMask: ioctl(sock, SIOCGIFADDR, &ifr) failed:", strerror( errno ));
+        close(sock);
+        return -1;
+    }
+    struct in_addr existing_src_ip = ((struct sockaddr_in *)&ifr.ifr_addr)->sin_addr;
+
+    // Fetch existing destination IP - proper one or dummy
+    memset(&ifr, 0, sizeof(ifr));
+    strncpy(ifr.ifr_name, pszNetDevName, IFNAMSIZ);
+    if (ioctl(sock, SIOCGIFDSTADDR, &ifr) < 0) {
+        WRMSG( HHC99998, "E", "TUNTAP_SetNetMask: ioctl(sock, SIOCGIFDSTADDR, &ifr) failed:", strerror( errno ));
+        close(sock);
+        return -1;
+        }
+    struct in_addr existing_dst_ip = ((struct sockaddr_in*)&ifr.ifr_addr)->sin_addr;
+
+    // Create request
+    struct in_aliasreq ifra;
+    memset(&ifra, 0, sizeof(ifra));
+    strncpy(ifra.ifra_name, pszNetDevName, IFNAMSIZ);
+
+    struct sockaddr_in* tmp_sin;
+
+    // Source address
+    tmp_sin = (struct sockaddr_in*)&ifra.ifra_addr;
+    tmp_sin->sin_len = sizeof(struct sockaddr_in);
+    tmp_sin->sin_family = AF_INET;
+    tmp_sin->sin_addr = existing_src_ip;
+
+    // Destination address
+    tmp_sin = (struct sockaddr_in*)&ifra.ifra_dstaddr;
+    tmp_sin->sin_len = sizeof(struct sockaddr_in);
+    tmp_sin->sin_family = AF_INET;
+    tmp_sin->sin_addr = existing_dst_ip;
+
+    // Netmask
+    // We have the 'real' netmask now, so we can overwrite the default 255.255.255.255 netmask.
+    tmp_sin = (struct sockaddr_in*)&ifra.ifra_mask;
+    tmp_sin->sin_len = sizeof(struct sockaddr_in);
+    tmp_sin->sin_family = AF_INET;
+    if (inet_pton(AF_INET, pszNetMask, &tmp_sin->sin_addr) != 1) {
+        WRMSG( HHC99998, "E", "TUNTAP_SetNetMask: inet_pton(AF_INET, pszNetMask, &tmp_sin->sin_addr) failed:", strerror( errno ));
+        close(sock);
+        return 1;
+    }
+
+    if (ioctl(sock, SIOCAIFADDR, &ifra) < 0) {
+        WRMSG( HHC99998, "E", "TUNTAP_SetNetMask: ioctl(sock, SIOCAIFADDR, &ifra) failed:", strerror( errno ));
+        close(sock);
+        return -1;
+    }
+
+    close(sock);
+    return 0;
+#else
+
     struct hifr         hifr;
     struct sockaddr_in* sin;
 
@@ -455,6 +836,7 @@ int           TUNTAP_SetNetMask( char*  pszNetDevName,
     }
 
     return TUNTAP_IOCtl( 0, SIOCSIFNETMASK, (char*)&hifr );
+#endif // defined (__FreeBSD__)
 }   // End of function  TUNTAP_SetNetMask()
 #endif // OPTION_TUNTAP_SETNETMASK
 
@@ -503,6 +885,12 @@ int             TUNTAP_SetIPAddr6( char*  pszNetDevName,
                                    char*  pszIPAddr6,
                                    char*  pszPrefixSize6 )
 {
+#if defined (__FreeBSD__)
+    // Soon, soon
+    WRMSG( HHC99999, "I", "TUNTAP_SetIPAddr6: IPv6 has not been implemented yet." );
+    return 0;
+#else
+
     struct hifr         hifr;
     int                 iPfxSiz;
 
@@ -550,6 +938,7 @@ int             TUNTAP_SetIPAddr6( char*  pszNetDevName,
     hifr.hifr_afamily = AF_INET6;
 
     return TUNTAP_IOCtl( 0, SIOCSIFADDR, (char*)&hifr );
+#endif // defined (__FreeBSD__)
 }   // End of function  TUNTAP_SetIPAddr6()
 #endif /* defined(ENABLE_IPV6) */
 
